@@ -175,7 +175,7 @@ class SocialToken(models.Model):
         verbose_name_plural = _("social application tokens")
 
     def __str__(self):
-        return self.token
+        return "%s (%s)" % (self._meta.verbose_name, self.pk)
 
 
 class SocialLogin(object):
